@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 '''
-    Copyright 2016 Kulik Lab @ MIT
+    Copyright 2017 Kulik Lab @ MIT
 
     This file is part of molSimplify.
     molSimplify is free software: you can redistribute it and/or modify
@@ -78,7 +78,7 @@ def startgen(argv,flag,gui):
         print ss
     sys.argv = argv
     parser = argparse.ArgumentParser()
-    args = parsecommandline(parser)
+    args = parseall(parser)
     # check if input file exists
     if not glob.glob(args.i):
         emsg = 'Input file '+args.i+' does not exist. Please specify a valid input file.\n'
@@ -86,13 +86,14 @@ def startgen(argv,flag,gui):
         return emsg
     args.gui = gui # add gui flag
         # parse input file
-    if (args.i):
-        parseinput(args)
-    # clean input arguments
-    cleaninput(args)
+    if args.i:
+        parseinputfile(args)
     if not args.postp and not args.dbsearch and not args.dbfinger and not (args.slab_gen or args.place_on_slab) and not (args.chain) and not (args.correlate):        # check input arguments
         # check input arguments
+        print 'Checking input...'
         emsg = checkinput(args)
+        # check before cleaning input arguments and clean only if checked
+        cleaninput(args)
     args.gui = False # deepcopy will give error
     if emsg:
         del args
@@ -167,6 +168,7 @@ def startgen(argv,flag,gui):
     ss =  "\n**************************************************************"
     ss += "\n***** Thank you for using "+PROGRAM+". Have a nice day! ******\n"
     ss += "**************************************************************"
+    ss += globs.about
     if not flag:
         print ss
     del args
